import os
import subprocess
import os
import click
from pathlib import Path
from datetime import datetime
import logging


@click.command("commit-push")
@click.option(
    "--repo-path", "-p", "repo_path", help="path to commit", default=Path().cwd()
)
def cli(repo_path):
    """
    Commits and pushes changes in the specified Git repository.
    """
    commit_message = f"{datetime.now().strftime('%Y-%m-%d')} daily publish"
    os.chdir(repo_path)

    try:
        # Run git add (add all changes)
        subprocess.run(["git", "add", "."], check=True)

        # Run git commit
        subprocess.run(["git", "commit", "-m", commit_message], check=True)

        # Run git push
        subprocess.run(["git", "push"], check=True)

        click.echo(
            f"changes have been committed and pushed to {repo_path} with message: {commit_message}"
        )
        logging.info("git pushed")

    except subprocess.CalledProcessError as e:
        logging.warning(f"error occurred while running git command: {e}")
        click.echo(f"error occurred while running git command: {e}")


if __name__ == "__main__":
    cli()
